package
Version:
v0.0.0-...-5a2029e
Opens a new window with list of versions in this module.
Published: Aug 25, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Spec struct {
OpUser string
}
Spec is the task-related task's specification
Status is the task-related task's status
Task represent an PodVMGroup task
Source Files
¶
Click to show internal directories.
Click to hide internal directories.